@@ -21,6 +21,7 @@ import os
 import pipes
 import re
 import shutil
+from subprocess import check_output
 import sys
 
 from contextlib import contextmanager
@@ -32,10 +33,21 @@ PYZMQ_ROOT = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 sys.path.insert(0, PYZMQ_ROOT)
 from buildutils.bundle import vs as libzmq_vs
 
+libsodium_version = '1.0.17'
+
 pjoin = os.path.join
 
 repo = 'git@github.com:zeromq/pyzmq'
-branch = 'master'
+branch = os.getenv('PYZMQ_BRANCH', 'master')
+sdkroot = os.getenv("SDKROOT")
+if not sdkroot:
+    xcode_prefix = check_output(["xcode-select", "-p"]).decode().strip()
+    # 10.9
+    sdkroot = os.path.join(xcode_prefix, "Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.9.sdk")
+    if os.path.exists(sdkroot):
+        os.environ["SDKROOT"] = sdkroot
+    else:
+        print("SDK not found at %r" % sdkroot)
 
 # Workaround for PyPy3 5.8
 if 'LDFLAGS' not in os.environ:
@@ -223,11 +235,23 @@ def manylinux(ctx, vs, upload=False):
 
     run("docker pull quay.io/pypa/manylinux1_x86_64")
     run("docker pull quay.io/pypa/manylinux1_i686")
-    base_cmd = "docker run --dns 8.8.8.8 --rm -e PYZMQ_VERSIONS='{vs}' -e PYTHON_VERSIONS='{pys}' -e ZMQ_VERSION='{zmq}' -v $PWD:/io".format(
-        vs=vs,
-        pys=manylinux_pys,
-        zmq=libzmq_vs,
-    )
+    base_cmd = ' '.join([
+        "docker",
+        "run",
+        "--dns=8.8.8.8",
+        "--rm",
+        "-e",
+        "PYZMQ_VERSIONS='{}'".format(vs),
+        "-e",
+        "PYTHON_VERSIONS='{}'".format(manylinux_pys),
+        "-e",
+        "ZMQ_VERSION='{}'".format(libzmq_vs),
+        "-e",
+        "LIBSODIUM_VERSION='{}'".format(libsodium_version),
+        "-v",
+        "$PWD:/io",
+    ])
+
     with cd(manylinux):
         run(base_cmd +  " quay.io/pypa/manylinux1_x86_64 /io/build_pyzmqs.sh")
         run(base_cmd +  " quay.io/pypa/manylinux1_i686 linux32 /io/build_pyzmqs.sh")
